@@ -1560,7 +1560,7 @@ namespace __gnu_cxx
 /* Define if C99 functions in <complex.h> should be used in <complex> for
    C++11. Using compiler builtins for these functions requires corresponding
    C99 library functions to be present. */
-#define _GLIBCXX11_USE_C99_COMPLEX 1
+/* #undef _GLIBCXX11_USE_C99_COMPLEX */
 
 /* Define if C99 generic macros in <math.h> should be imported in <cmath> in
    namespace std for C++11. */
@@ -1581,7 +1581,7 @@ namespace __gnu_cxx
 /* Define if C99 functions in <complex.h> should be used in <complex> for
    C++98. Using compiler builtins for these functions requires corresponding
    C99 library functions to be present. */
-#define _GLIBCXX98_USE_C99_COMPLEX 1
+/* #undef _GLIBCXX98_USE_C99_COMPLEX */
 
 /* Define if C99 functions or macros in <math.h> should be imported in <cmath>
    in namespace std for C++98. */
@@ -1675,7 +1675,7 @@ namespace __gnu_cxx
 
 /* Define if C99 functions or macros from <wchar.h>, <math.h>, <complex.h>,
    <stdio.h>, and <stdlib.h> can be used or exposed. */
-#define _GLIBCXX_USE_C99 1
+/* #undef _GLIBCXX_USE_C99 */
 
 /* Define if C99 inverse trig functions in <complex.h> should be used in
    <complex>. Using compiler builtins for these functions requires
